@@ -10,7 +10,7 @@ import sys
 import inspect
 from functools import partial
 
-def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer, global_rounds, local_steps, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')):
+def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer, global_rounds, local_steps, reg = None, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')):
     # dt = data_process(dataset)
     # train_splited, test_splited = dt.split_dataset(num_nodes, split['split_para'], split['split_method'])
     train_splited, test_splited, split_para = dataset_splited
@@ -41,7 +41,10 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
         print('-------------------Global round %d start-------------------' % (i))
         # local update
         for j in range(num_nodes):
-            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step))
+            if not reg:
+                nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step))
+            else:
+                nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_fedprox, reg_model = server.aggregate(nodes, list(range(num_nodes))), lam= reg))
         # server clustering
         server.weighted_clustering(nodes, list(range(num_nodes)), K)
         # server aggregation and distribution by cluster
@@ -54,4 +57,4 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
         server.acc(nodes, list(range(num_nodes)))
     
     # log
-    log(os.path.basename(__file__)[:-3] + '_' + str(K) + '_' + split_para, nodes, server)
\ No newline at end of file
+    log(os.path.basename(__file__)[:-3] + '_' + str(K) + '_' + str(reg) + '_' + split_para, nodes, server)
\ No newline at end of file
